@@ -34,7 +34,7 @@ __copyright__ = "This software is copyrighted to Galen Data and is only availabl
                 "License are non transferable unless agreed upon in the subscription contract. "
 __credits__ = ["Nathanael Goza", "Abbas Dhilawala"]
 __license__ = "Proprietary"
-__version__ = "1.0.1"
+__version__ = "3.0.0"
 __maintainer__ = "Nathanael Goza"
 __email__ = "support@galendata.com"
 __status__ = "Development"
@@ -152,15 +152,15 @@ class SDK:
             IllegalArgumentException: API version is required
 
         """
-        if (apiUrl == None or apiUrl.strip() == ''):
+        if (apiUrl is None or apiUrl.strip() == ''):
             raise IllegalArgumentException("API URL is required")
         self.apiURL = apiUrl
 
-        if (tenantDomainName == None or tenantDomainName.strip() == ''):
+        if (tenantDomainName is None or tenantDomainName.strip() == ''):
             raise IllegalArgumentException("Tenant domain name is required")
         self.tenantDomainName = tenantDomainName
 
-        if (apiVersion == None or apiVersion.strip() == ''):
+        if (apiVersion is None or apiVersion.strip() == ''):
             raise IllegalArgumentException("API version is required")
         else:
             self.apiVersion = apiVersion
@@ -171,7 +171,7 @@ class SDK:
 
         self.tenantDomainName = tenantDomainName
 
-        if (authToken != None and authToken.strip() == ""):
+        if (authToken is not None and authToken.strip() != ""):
             self.authToken = authToken
 
     def login(self, emailAddress: str, password: str) -> User:
@@ -198,7 +198,7 @@ class SDK:
             "emailAddress": emailAddress,
             "password": password
         }
-        response = requests.request("POST", url, headers=my_headers, data=data)
+        response = requests.post(url, headers=my_headers, data=data)
 
         # SUCCESS
         if (check_http_status(response)):
@@ -222,7 +222,7 @@ class SDK:
             self.API_VERSION_HEADER: self.apiVersion,
             self.APP_TYPE_HEADER: "DEVICE"
         }
-        response = requests.request("POST", url, headers=my_headers, data=master_token)
+        response = requests.post(url, headers=my_headers, data=master_token)
 
         if (check_http_status(response)):
             # grabs the authtoken and stores it in the sdk
@@ -260,7 +260,7 @@ class SDK:
             self.APP_TYPE_HEADER: "DEVICE"
         }
 
-        response = requests.request("GET", url, headers=my_headers)
+        response = requests.get(url, headers=my_headers)
 
         jsonHolder = response.json()
         customDataHolder = []
@@ -283,7 +283,7 @@ class SDK:
             self.APP_TYPE_HEADER: "DEVICE"
         }
 
-        response = requests.request("GET", url, headers=my_headers)
+        response = requests.get(url, headers=my_headers)
 
         jsonHolder = response.json()
         customDataHolder = []
@@ -305,7 +305,7 @@ class SDK:
             self.APP_TYPE_HEADER: "DEVICE"
         }
 
-        response = requests.request("GET", url, headers=my_headers)
+        response = requests.get(url, headers=my_headers)
 
         jsonHolder = response.json()
         customDataHolder = []
@@ -330,7 +330,7 @@ class SDK:
         }
 
         data = json.dumps(field.__dict__())
-        response = requests.request("POST", url, headers=my_headers, data=data)
+        response = requests.post(url, headers=my_headers, data=data)
 
         if check_http_status(response):
             return True
@@ -377,7 +377,7 @@ class SDK:
             "customFieldId": customFieldId
         }
 
-        response = requests.request("DELETE", url, headers=my_headers, params=data)
+        response = requests.delete(url, headers=my_headers, params=data)
 
         if check_http_status(response):
             return True
@@ -397,7 +397,7 @@ class SDK:
             self.APP_TYPE_HEADER: "DEVICE"
         }
 
-        response = requests.request("GET", url, headers=my_headers)  # , params=data)
+        response = requests.get(url, headers=my_headers)
 
         if check_http_status(response):
             return CustomField.from_json(response.json())
@@ -417,7 +417,7 @@ class SDK:
             self.APP_TYPE_HEADER: "DEVICE"
         }
 
-        response = requests.request("GET", url, headers=my_headers)
+        response = requests.get(url, headers=my_headers)
 
         if check_http_status(response):
             user_holder = User.from_json(response.json())
@@ -439,7 +439,7 @@ class SDK:
             self.APP_TYPE_HEADER: "DEVICE"
         }
 
-        response = requests.request("GET", url, headers=my_headers)
+        response = requests.get(url, headers=my_headers)
 
         if check_http_status(response):
             user_holder = User.from_json(response.json())
@@ -499,7 +499,7 @@ class SDK:
             if pageInfo.get_sort_order() is not None:
                 data["sortOrder"] = SortOrder.to_string(pageInfo.get_sort_order())
 
-        response = requests.request("GET", url, headers=my_headers, params=data)
+        response = requests.get(url, headers=my_headers, params=data)
 
         if check_http_status(response):
             # turns the [json user] content into [User]
@@ -548,7 +548,7 @@ class SDK:
             "password": password,
             "customData": customDataIn
         }
-        response = requests.request("POST", url, headers=my_headers, data=json.dumps(data))
+        response = requests.post(url, headers=my_headers, data=json.dumps(data))
 
         if check_http_status(response):
             return True
@@ -583,7 +583,6 @@ class SDK:
 
         data = {
             "user": user.__dict__()
-            # "customData" : customDataIn
         }
         response = requests.request("PUT", url, headers=my_headers, data=json.dumps(data))
         if check_http_status(response):
@@ -609,7 +608,7 @@ class SDK:
         data = {
             "userId": userId
         }
-        response = requests.request("DELETE", url, headers=my_headers, data=data)
+        response = requests.delete(url, headers=my_headers, data=data)
 
         if check_http_status(response):
             return True
@@ -679,7 +678,7 @@ class SDK:
             "customData": customDataIn,
             "supplier": supplier.__dict__()
         }
-        response = requests.request("POST", url, headers=my_headers, data=json.dumps(data))
+        response = requests.post(url, headers=my_headers, data=json.dumps(data))
 
         if check_http_status(response):
             return True
@@ -730,7 +729,7 @@ class SDK:
             self.APP_TYPE_HEADER: "DEVICE"
         }
 
-        response = requests.request("GET", url, headers=my_headers)
+        response = requests.get(url, headers=my_headers)
 
         if check_http_status(response):
             supplierHolder = Supplier.from_json(response.json())
@@ -779,7 +778,7 @@ class SDK:
             if pageInfo.get_sort_order() is not None:
                 data["sortOrder"] = SortOrder.to_string(pageInfo.get_sort_order())
 
-        response = requests.request("GET", url, headers=my_headers, params=data)
+        response = requests.get(url, headers=my_headers, params=data)
 
         if check_http_status(response):
             pageHolder = Page.from_json(response.json())
@@ -807,7 +806,7 @@ class SDK:
         data = {
             "supplierId": supplierId
         }
-        response = requests.request("DELETE", url, headers=my_headers, data=data)
+        response = requests.delete(url, headers=my_headers, data=data)
 
         if check_http_status(response):
             return True
@@ -841,7 +840,7 @@ class SDK:
             "customData": customDataIn,
             "practice": practice.__dict__()
         }
-        response = requests.request("POST", url, headers=my_headers, data=json.dumps(data))
+        response = requests.post(url, headers=my_headers, data=json.dumps(data))
 
         if check_http_status(response):
             return True
@@ -890,14 +889,14 @@ class SDK:
             self.APP_TYPE_HEADER: "DEVICE"
         }
 
-        response = requests.request("GET", url, headers=my_headers)
+        response = requests.get(url, headers=my_headers)
 
         if check_http_status(response):
             practiceHolder = Practice.from_json(response.json())
             return practiceHolder
 
     def get_practices(self, name: str = None, status: Status = None,
-                      pageInfo: PageInfo = None) -> Page:  # emailAddress: str = None,
+                      pageInfo: PageInfo = None) -> Page:
         """
         Retrieve a page of Practices that fit the given filters
         :param name: name of Practice you want to get. String. Optional.
@@ -924,7 +923,6 @@ class SDK:
 
         data = {
             'name': name,
-            # "emailAddress": emailAddress,         # :param emailAddress: emailAddress of Practice you want to get. String. Optional.
             "status": Status.to_string(status)
         }
         if pageInfo is not None:
@@ -941,7 +939,7 @@ class SDK:
             if pageInfo.get_sort_order() is not None:
                 data["sortOrder"] = SortOrder.to_string(pageInfo.get_sort_order())
 
-        response = requests.request("GET", url, headers=my_headers, params=data)
+        response = requests.get(url, headers=my_headers, params=data)
 
         if check_http_status(response):
             page_holder = Page.from_json(response.json())
@@ -969,7 +967,7 @@ class SDK:
         data = {
             "practiceId": practiceId
         }
-        response = requests.request("DELETE", url, headers=my_headers, data=data)
+        response = requests.delete(url, headers=my_headers, data=data)
 
         if check_http_status(response):
             return True
@@ -994,7 +992,7 @@ class SDK:
                 Height                      Number
                 Blood Pressure              String with "systolic-pressure-value/diastolic-pressure-value"
                 Dropdown List               String with the Dropdown Option as its innards ie) "Dropdown Value 3"
-                Geographical Cooridnates    String that represents the coordinates
+                Geographical Coordinates    String that represents the coordinates
                 Number                      Number
                 Number Array                Number Array
                 Temperature                 Number
@@ -1022,14 +1020,13 @@ class SDK:
             "ownerId": ownerId,
             "data": data
         }
-        response = requests.request("POST", url, headers=my_headers, data=json.dumps(data))
+        response = requests.post(url, headers=my_headers, data=json.dumps(data))
 
         if check_http_status(response):
             return response.content.decode("utf-8")
         return " "
 
-    def save_data_bulk(self, deviceDataModelId: str, devicePropertySetId: str,
-                       dataList: [DeviceData]):  # , deviceDataId:str, ownerId:str
+    def save_data_bulk(self, deviceDataModelId: str, devicePropertySetId: str, dataList: [DeviceData]):
         """
         :param deviceDataModelId: deviceDataModelId. Required.       [Device Data > manage Data > in URL]
         :param devicePropertySetId: devicePropertySetId. Required.   [Devices List > Edit > Data model edit > in URL]
@@ -1051,12 +1048,11 @@ class SDK:
             dataListDicts.append(dl.__dict__())
 
         data = {
-            # "deviceDataId": deviceDataId,
             "deviceDataModelId": deviceDataModelId,
             "devicePropertySetId": devicePropertySetId,
             "dataArray": dataListDicts
         }
-        response = requests.request("POST", url, headers=my_headers, data=json.dumps(data))
+        response = requests.post(url, headers=my_headers, data=json.dumps(data))
 
         if check_http_status(response):
             # turns byte data into a list of strings that represent the data ID
@@ -1076,7 +1072,6 @@ class SDK:
         :param fileName: name of the mediaFile. Include the extension. Required.
         :return: True if successful, False otherwise
         """
-        # print("saving data")
         url = self.apiURL + self.DEVICEDATA_GET_MEDIA_URL + deviceDataId
         my_headers = {
             self.TENANT_DOMAIN_HEADER: self.tenantDomainName,
@@ -1091,7 +1086,7 @@ class SDK:
         files = {
             'data': (fileName, mediaFile, "application/octet-stream")
         }
-        response = requests.request("POST", url, headers=my_headers, files=files, params=data)
+        response = requests.post(url, headers=my_headers, files=files, params=data)
 
         if check_http_status(response):
             return True
@@ -1110,11 +1105,7 @@ class SDK:
             self.AUTHENTICATION_TOKEN_HEADER: self.authToken,
             self.APP_TYPE_HEADER: "DEVICE"
         }
-        data = {
-            # "deviceId": deviceId,
-            # "deviceDataId": deviceDataId
-        }
-        response = requests.request("GET", url, headers=my_headers)  # , data=data)
+        response = requests.get(url, headers=my_headers)
 
         if check_http_status(response):
             device_data = DeviceData.from_json(response.json())
@@ -1134,7 +1125,6 @@ class SDK:
         :param pageInfo: Extra parameters to change what data is returned
         :return: Page with the contents variable being a list of device data
         """
-        # This is different for V3 and V2 so Continue Here
         url = self.apiURL + self.DEVICEDATA_GET_ADVANCED_URL
         my_headers = {
             self.TENANT_DOMAIN_HEADER: self.tenantDomainName,
@@ -1166,11 +1156,11 @@ class SDK:
             "deviceDataModelId": deviceDataModelId,
             "rangeStartDateTime": (date_time_formater(startDateTime) if startDateTime else ""),
             "rangeEndDateTime": (date_time_formater(endDateTime) if endDateTime else ""),
-            "devicePropertyCodes": propertyCodes,  # ?
+            "devicePropertyCodes": propertyCodes,
             "ownerFilter": (ownerFilter.__dict__() if ownerFilter is not None else None),
             "deviceCriteria": device_criteria_dict_list
         }
-        response = requests.request("POST", url, headers=my_headers, params=query, data=json.dumps(data))
+        response = requests.post(url, headers=my_headers, params=query, data=json.dumps(data))
 
         if check_http_status(response):
             page_device_data = Page.from_json(response.json())
@@ -1229,11 +1219,11 @@ class SDK:
             "deviceDataModelId": deviceDataModelId,
             "rangeStartDateTime": date_time_formater(startDateTime),
             "rangeEndDateTime": date_time_formater(endDateTime),
-            "devicePropertyCodes": propertyCodes,  # ?
+            "devicePropertyCodes": propertyCodes,
             "ownerFilter": (ownerFilter.__dict__() if ownerFilter is not None else None),
             "deviceCriteria": device_criteria_dict_list
         }
-        response = requests.request("POST", url, headers=my_headers, params=query, data=json.dumps(data))
+        response = requests.post(url, headers=my_headers, params=query, data=json.dumps(data))
 
         if check_http_status(response):
             page_device_data = Page.from_json(response.json())
@@ -1270,7 +1260,7 @@ class SDK:
             self.APP_TYPE_HEADER: "DEVICE"
         }
 
-        response = requests.request("GET", url, headers=my_headers)
+        response = requests.get(url, headers=my_headers)
 
         if check_http_status(response):
             return response.content
@@ -1312,7 +1302,7 @@ class SDK:
             "rangeEndDateTime": date_time_formater(rangeEndDateTime),
             "rangeStartDateTime": date_time_formater(rangeStartDateTime)
         }
-        response = requests.request("POST", url, headers=my_headers, data=json.dumps(data))
+        response = requests.post(url, headers=my_headers, data=json.dumps(data))
 
         if check_http_status(response):
             return True
@@ -1329,7 +1319,7 @@ class SDK:
         return practice
 
     def get_practices_with_custom_data(self, name: str = None, status: Status = None,
-                                       pageInfo: PageInfo = None) -> Page:  # emailAddress: str = None,
+                                       pageInfo: PageInfo = None) -> Page:
         """
         Retrieve a page of Practices that fit the given filters
         :param name: name of Practice you want to get. String. Optional.
@@ -1345,8 +1335,7 @@ class SDK:
             :PageInfo param sortOrder: SortOrder of the resultant Page output you want. Default is Ascending. SortOrder. Optional.
         :return: Page with Practices in the content portion of the page. Including any customData
         """
-        practices_page = self.get_practices(name, status,
-                                            pageInfo)  # emailAddress,         :param emailAddress: emailAddress of Practice you want to get. String. Optional.
+        practices_page = self.get_practices(name, status, pageInfo)
 
         # makes a new content list to store all the practices now including customData and then fills it out
         content_with_custom_data = []
