@@ -13,6 +13,12 @@ class DataOperator(Enum):
     LessThanOrEqual = 5
     Like = 6
     Between = 7
+    NotEqual = 8
+    UnLike = 9
+    StartsWith = 10
+    EndsWith = 11
+    IsSet = 12
+    NotSet = 13
 
     @staticmethod
     def to_string(data_operator) -> str:
@@ -36,4 +42,16 @@ class DataOperator(Enum):
             return "Like"
         if data_operator == DataOperator.Between:
             return "Between"
+        if data_operator == DataOperator.NotEqual:
+            return "NotEqual"
+        if data_operator == DataOperator.UnLike:
+            return "UnLike"
+        if data_operator == DataOperator.StartsWith:
+            return "StartsWith"
+        if data_operator == DataOperator.EndsWith:
+            return "EndsWith"
+        if data_operator == DataOperator.IsSet:
+            return "IsSet"
+        if data_operator == DataOperator.NotSet:
+            return "NotSet"
         return ""
