@@ -8,6 +8,8 @@ from enum import Enum
 class Gender (Enum):
     MALE = 1
     FEMALE = 2
+    OTHER = 3
+    UNKNOWN = 4
 
     @staticmethod
     def to_string(gender) -> str:
@@ -21,6 +23,10 @@ class Gender (Enum):
             return "MALE"
         if gender == Gender.FEMALE:
             return "FEMALE"
+        if gender == Gender.OTHER:
+            return "OTHER"
+        if gender == Gender.UNKNOWN:
+            return "UNKNOWN"
         return None
 
     @staticmethod
@@ -35,4 +41,8 @@ class Gender (Enum):
             return Gender.MALE
         if string_gender.upper() == "FEMALE":
             return Gender.FEMALE
+        if string_gender.upper() == "OTHER":
+            return Gender.OTHER
+        if string_gender.upper() == "UNKNOWN":
+            return Gender.UNKNOWN
         return None
